package App::vcardtidy;
use strict;
use warnings;

our $VERSION = 'v1.0.4';

1;

__END__

=head1 NAME

App::vcardtidy - a placeholder package to index vcardtidy(1)

=head1 DESCRIPTION

See L<vcardtidy>(1)

=head1 AUTHOR

Mark Lawrence E<lt>nomad@null.netE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2022 Mark Lawrence <nomad@null.net>

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.

